Module element_type

Module element_type 

Element type definitions for Windows Batch (BAT) syntax tree nodes.

This module provides BatElementType which defines all element types used in the BAT parse tree, including statements, labels, and commands.

Enums

BatElementType
Represents all possible element kinds in the Windows Batch (BAT) scripting language.